obelisk.sync.producer.Producer
==============================

.. currentmodule:: obelisk.sync.producer

.. autoclass:: Producer
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Producer.__init__
      ~Producer.send
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Producer.loop
      ~Producer.async_producer
   
   